@@ -65,6 +65,11 @@ public:
 	void alsa_capture(snd_seq_event_t *ev);
 #endif
 
+#ifdef CONFIG_JACK_SESSION
+	// JACK session event handler.
+	void sessionEvent(void *pvSessionArg);
+#endif
+
 private:
 
 	jack_client_t *m_client;
@@ -95,6 +100,75 @@ private:
 };
 
 
+//-------------------------------------------------------------------------
+// samplv1_application -- Singleton application instance.
+//
+
+#include <QObject>
+#include <QStringList>
+
+
+// forward decls.
+class QCoreApplication;
+class samplv1widget_jack;
+
+#ifdef CONFIG_NSM
+class samplv1_nsm;
+#endif
+
+
+class samplv1_application : public QObject
+{
+	Q_OBJECT
+
+public:
+
+	// Constructor.
+	samplv1_application(int& argc, char **argv);
+
+	// Destructor.
+	~samplv1_application();
+
+	// Facade method.
+	int exec();
+
+#ifdef CONFIG_NSM
+
+protected slots:
+
+	// NSM callback slots.
+	void openSession();
+	void saveSession();
+
+	void hideSession();
+	void showSession();
+
+#endif	// CONFIG_NSM
+
+protected:
+
+	// Argument parser method.
+	bool parse_args();
+
+	// Startup method.
+	bool setup();
+
+private:
+
+	// Instance variables.
+	QCoreApplication *m_pApp;
+	bool m_bGui;
+	QStringList m_presets;
+
+	samplv1_jack *m_pSampl;
+	samplv1widget_jack *m_pWidget;
+
+#ifdef CONFIG_NSM
+	samplv1_nsm *m_pNsmClient;
+#endif
+};
+
+
 #endif// __samplv1_jack_h
 
 // end of samplv1_jack.h
