@@ -173,8 +173,6 @@ void samplv1_param::loadSamples (
 			pSampl->setLoopRange(iLoopStart, iLoopEnd);
 		}
 	}
-
-	pSampl->reset();
 }
 
 
@@ -269,10 +267,10 @@ void samplv1_param::loadPreset ( samplv1 *pSampl, const QString& sFilename )
 								index = s_hash.value(sName);
 							}
 							float fParamValue = eParam.text().toFloat();
-						//--legacy support < 0.3.0.4 -- begin
+						#if 1//--legacy support < 0.3.0.4
 							if (index == samplv1::DEL1_BPM && fParamValue < 3.6f)
 								fParamValue *= 100.0f;
-						//--legacy support < 0.3.0.4 -- end.
+						#endif
 							float *pfParamPort = pSampl->paramPort(index);
 							if (pfParamPort)
 								*pfParamPort = fParamValue;
