@@ -34,7 +34,7 @@ class samplv1_wave
 public:
 
 	// shape.
-	enum Shape { Pulse = 0, Saw, Sine, Noise };
+	enum Shape { Pulse = 0, Saw, Sine, Rand, Noise };
 
 	// ctor.
 	samplv1_wave(uint32_t nsize = 1024, uint16_t nover = 24);
@@ -130,6 +130,9 @@ protected:
 	// init sine table.
 	void reset_sine();
 
+	// init random table.
+	void reset_rand();
+
 	// init noise table.
 	void reset_noise();
 
@@ -142,7 +145,7 @@ protected:
 	uint32_t pseudo_srand ()
 		{ return (m_srand = (m_srand * 196314165) + 907633515); }
 	float pseudo_randf ()
-		{ return pseudo_srand() / float(1 << 16) - 1.0f; }
+		{ return pseudo_srand() / float(0x8000U << 16) - 1.0f; }
 
 private:
 
