@@ -97,6 +97,7 @@ samplv1widget::samplv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	for (int note = 0; note < 128; ++note)
 		notes << noteName(note);
 
+	m_ui.Gen1SampleKnob->setScale(1000.0f);
 	m_ui.Gen1SampleKnob->insertItems(0, notes);
 
 	// Swappable params A/B group.
@@ -155,6 +156,9 @@ samplv1widget::samplv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	m_ui.Gen1EnvTimeKnob->setSpecialValueText(sAuto);
 	m_ui.Del1BpmKnob->setSpecialValueText(sAuto);
 
+	// Wave integer widths.
+	m_ui.Lfo1WidthKnob->setDecimals(0);
+
 	// GEN note limits.
 	m_ui.Gen1SampleKnob->setMinimum(0.0f);
 	m_ui.Gen1SampleKnob->setMaximum(127.0f);
@@ -208,6 +212,7 @@ samplv1widget::samplv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	m_ui.Del1BpmKnob->setScale(1.0f);
 	m_ui.Del1BpmKnob->setMinimum(3.6f);
 	m_ui.Del1BpmKnob->setMaximum(360.0f);
+	m_ui.Del1BpmKnob->setSingleStep(1.0f);
 
 	// Reverb (stereo-)width limits.
 	m_ui.Rev1WidthKnob->setMinimum(-1.0f);
@@ -706,7 +711,7 @@ void samplv1widget::updateParamValues (void)
 			fValue = *pfParamPort;
 		setParamValue(index, fValue, true);
 		updateParam(index, fValue);
-		updateParamEx(index, fValue);
+	//	updateParamEx(index, fValue);
 		m_params_ab[index] = fValue;
 	}
 }
@@ -1027,10 +1032,8 @@ void samplv1widget::bpmSyncChanged (void)
 	if (pSampl) {
 		float *pBpmSync = pSampl->paramPort(samplv1::DEL1_BPMSYNC);
 		if (pBpmSync) {
-			const bool bBpmSync0
-				= (*pBpmSync > 0.0f);
-			const bool bBpmSync1
-				= (m_ui.Del1BpmKnob->minimum() >= m_ui.Del1BpmKnob->value());
+			const bool bBpmSync0 = (*pBpmSync > 0.0f);
+			const bool bBpmSync1 = m_ui.Del1BpmKnob->isSpecialValue();
 			if ((bBpmSync1 && !bBpmSync0) || (!bBpmSync1 && bBpmSync0))
 				*pBpmSync = (bBpmSync1 ? 1.0f : 0.0f);
 		}
