@@ -28,12 +28,9 @@
 
 #include "samplv1.h"
 
-#include <QHash>
 
-
-// forward decl.
-class QDomElement;
-class QDomDocument;
+// forward decls.
+class samplv1_sched_notifier;
 
 
 //-------------------------------------------------------------------------
@@ -49,6 +46,9 @@ public:
 	// Constructor
 	samplv1widget(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
 
+	// Destructor.
+	~samplv1widget();
+
 	// Param port accessors.
 	void setParamValue(
 		samplv1::ParamIndex index, float fValue, bool bDefault = false);
@@ -92,6 +92,9 @@ protected slots:
 	// Sample loader slot.
 	void loadSample(const QString& sFilename);
 
+	// Sample updater.
+	void updateSampleNotify();
+
 	// Common context menu.
 	void contextMenuRequest(const QPoint& pos);
 
@@ -110,6 +113,8 @@ protected slots:
 	void bpmSyncChanged();
 
 	// Menu actions.
+	void helpUseNativeDialogs(bool bOn);
+
 	void helpAbout();
 	void helpAboutQt();
 
@@ -121,6 +126,9 @@ protected:
 	// Reset swap params A/B group.
 	void resetSwapParams();
 
+	// Initialize all param/knob values.
+	void updateParamValues();
+
 	// Reset all param/knob default values.
 	void resetParamValues();
 	void resetParamKnobs();
@@ -134,7 +142,7 @@ protected:
 	// Sample file clearance.
 	void clearSampleFile();
 
-	// Sample loader slot.
+	// Sample loader.
 	void loadSampleFile(const QString& sFilename);
 
 	// Sample updater.
@@ -143,10 +151,6 @@ protected:
 	// Update loop range change status.
 	void updateSampleLoop(samplv1_sample *pSample, bool bDirty = false);
 
-	// Sample serialization methods.
-	void loadSamples(const QDomElement& eSamples);
-	void saveSamples(QDomDocument& doc, QDomElement& eSamples);
-
 	// Dirty flag (overridable virtual) methods.
 	virtual void updateDirtyPreset(bool bDirtyPreset);
 
@@ -157,6 +161,8 @@ private:
 
 	samplv1widget_config m_config;
 
+	samplv1_sched_notifier *m_sched_notifier;
+
 	QHash<samplv1::ParamIndex, samplv1widget_knob *> m_paramKnobs;
 	QHash<samplv1widget_knob *, samplv1::ParamIndex> m_knobParams;
 
