@@ -56,7 +56,6 @@ samplv1widget_knob::samplv1widget_knob ( QWidget *pParent ) : QWidget(pParent)
 	resetDefaultValue();
 
 	m_pLabel->setAlignment(Qt::AlignCenter);
-	m_pDial->setSingleStep(10);
 	m_pDial->setNotchesVisible(true);
 	m_pDial->setMaximumSize(QSize(48, 42));
 
@@ -80,6 +79,7 @@ void samplv1widget_knob::setText ( const QString& sText )
 	m_pLabel->setText(sText);
 }
 
+
 QString samplv1widget_knob::text (void) const
 {
 	return m_pLabel->text();
@@ -88,7 +88,7 @@ QString samplv1widget_knob::text (void) const
 
 void samplv1widget_knob::setValue ( float fValue, bool bDefault )
 {
-	bool bDialBlock = m_pDial->blockSignals(true);
+	const bool bDialBlock = m_pDial->blockSignals(true);
 
 	m_pDial->setValue(scaleFromValue(fValue));
 
@@ -107,11 +107,12 @@ void samplv1widget_knob::setValue ( float fValue, bool bDefault )
 	}
 	QWidget::setPalette(pal);
 
-	emit valueChanged(value());
+	emit valueChanged(fValue);
 
 	m_pDial->blockSignals(bDialBlock);
 }
 
+
 float samplv1widget_knob::value (void) const
 {
 	return valueFromScale(m_pDial->value());
@@ -120,7 +121,7 @@ float samplv1widget_knob::value (void) const
 
 QString samplv1widget_knob::valueText (void) const
 {
-	return QString::number(m_pDial->value());
+	return QString::number(value());
 }
 
 
@@ -129,6 +130,7 @@ void samplv1widget_knob::setMaximum ( float fMaximum )
 	m_pDial->setMaximum(scaleFromValue(fMaximum));
 }
 
+
 float samplv1widget_knob::maximum (void) const
 {
 	return valueFromScale(m_pDial->maximum());
@@ -140,6 +142,7 @@ void samplv1widget_knob::setMinimum ( float fMinimum )
 	m_pDial->setMinimum(scaleFromValue(fMinimum));
 }
 
+
 float samplv1widget_knob::minimum (void) const
 {
 	return valueFromScale(m_pDial->minimum());
@@ -152,12 +155,14 @@ void samplv1widget_knob::resetDefaultValue (void)
 	m_iDefaultValue = 0;
 }
 
+
 void samplv1widget_knob::setDefaultValue ( float fDefaultValue )
 {
 	m_fDefaultValue = fDefaultValue;
 	m_iDefaultValue++;
 }
 
+
 float samplv1widget_knob::defaultValue (void) const
 {
 	return m_fDefaultValue;
@@ -169,6 +174,7 @@ void samplv1widget_knob::setSingleStep ( float fSingleStep )
 	m_pDial->setSingleStep(scaleFromValue(fSingleStep));
 }
 
+
 float samplv1widget_knob::singleStep (void) const
 {
 	return valueFromScale(m_pDial->singleStep());
@@ -202,8 +208,11 @@ void samplv1widget_knob::dialValueChanged ( int iDialValue )
 void samplv1widget_knob::setScale ( float fScale )
 {
 	m_fScale = fScale;
+
+	m_pDial->setNotchTarget(valueFromScale(33.3f));
 }
 
+
 float samplv1widget_knob::scale (void) const
 {
 	return m_fScale;
@@ -211,14 +220,15 @@ float samplv1widget_knob::scale (void) const
 
 
 // Scale/value converters.
-int samplv1widget_knob::scaleFromValue ( float fValue ) const
+float samplv1widget_knob::scaleFromValue ( float fValue ) const
 {
-	return iroundf(m_fScale * fValue);
+	return (m_fScale * fValue);
 }
 
-float samplv1widget_knob::valueFromScale ( int iScale ) const
+
+float samplv1widget_knob::valueFromScale ( float fScale ) const
 {
-	return float(iScale) / m_fScale;
+	return (fScale / m_fScale);
 }
 
 
@@ -230,7 +240,7 @@ float samplv1widget_knob::valueFromScale ( int iScale ) const
 samplv1widget_spin::samplv1widget_spin ( QWidget *pParent )
 	: samplv1widget_knob(pParent)
 {
-	m_pSpinBox = new QSpinBox();
+	m_pSpinBox = new QDoubleSpinBox();
 	m_pSpinBox->setAccelerated(true);
 	m_pSpinBox->setAlignment(Qt::AlignCenter);
 
@@ -244,15 +254,18 @@ samplv1widget_spin::samplv1widget_spin ( QWidget *pParent )
 	setMinimum(0.0f);
 	setMaximum(1.0f);
 
+	setDecimals(1);
+
 	QObject::connect(m_pSpinBox,
-		SIGNAL(valueChanged(int)),
-		SLOT(spinBoxValueChanged(int)));
+		SIGNAL(valueChanged(double)),
+		SLOT(spinBoxValueChanged(double)));
 }
 
 
+// Virtual accessors.
 void samplv1widget_spin::setValue ( float fValue, bool bDefault )
 {
-	bool bSpinBlock = m_pSpinBox->blockSignals(true);
+	const bool bSpinBlock = m_pSpinBox->blockSignals(true);
 
 	m_pSpinBox->setValue(scaleFromValue(fValue));
 	samplv1widget_knob::setValue(fValue, bDefault);
@@ -275,10 +288,29 @@ void samplv1widget_spin::setMinimum ( float fMinimum )
 }
 
 
-// Internal widget slots.
-void samplv1widget_spin::spinBoxValueChanged ( int iSpinValue )
+void samplv1widget_spin::setSingleStep ( float fSingleStep )
 {
-	setValue(valueFromScale(iSpinValue));
+	m_pSpinBox->setSingleStep(fSingleStep);
+	samplv1widget_knob::setSingleStep(fSingleStep);
+}
+
+
+QString samplv1widget_spin::valueText (void) const
+{
+	return QString::number(m_pSpinBox->value());
+}
+
+
+float samplv1widget_spin::value (void) const
+{
+	return float(m_pSpinBox->value());
+}
+
+
+// Internal widget slots.
+void samplv1widget_spin::spinBoxValueChanged ( double spinValue )
+{
+	samplv1widget_knob::setValue(valueFromScale(float(spinValue)));
 }
 
 
@@ -288,12 +320,33 @@ void samplv1widget_spin::setSpecialValueText ( const QString& sText )
 	m_pSpinBox->setSpecialValueText(sText);
 }
 
+
 QString samplv1widget_spin::specialValueText (void) const
 {
 	return m_pSpinBox->specialValueText();
 }
 
 
+bool samplv1widget_spin::isSpecialValue (void) const
+{
+	return (m_pSpinBox->minimum() >= m_pSpinBox->value());
+}
+
+
+// Decimal digits allowed.
+void samplv1widget_spin::setDecimals ( int iDecimals )
+{
+	m_pSpinBox->setDecimals(iDecimals);
+
+	setSingleStep(::powf(10.0f, - float(iDecimals)));
+}
+
+int samplv1widget_spin::decimals (void) const
+{
+	return m_pSpinBox->decimals();
+}
+
+
 //-------------------------------------------------------------------------
 // samplv1widget_combo - Custom knob/combo-box widget.
 //
@@ -307,8 +360,6 @@ samplv1widget_combo::samplv1widget_combo ( QWidget *pParent )
 	const QFontMetrics fm(samplv1widget_knob::font());
 	m_pComboBox->setMaximumHeight(fm.height() + 6);
 
-	setSingleStep(1);
-
 	QGridLayout *pGridLayout
 		= static_cast<QGridLayout *> (QWidget::layout());
 	pGridLayout->addWidget(m_pComboBox, 2, 0, 1, 3);
@@ -319,11 +370,12 @@ samplv1widget_combo::samplv1widget_combo ( QWidget *pParent )
 }
 
 
+// Virtual accessors.
 void samplv1widget_combo::setValue ( float fValue, bool bDefault )
 {
-	bool bComboBlock = m_pComboBox->blockSignals(true);
+	const bool bComboBlock = m_pComboBox->blockSignals(true);
 
-	int iValue = iroundf(fValue);
+	const int iValue = iroundf(fValue);
 	m_pComboBox->setCurrentIndex(iValue);
 	samplv1widget_knob::setValue(float(iValue), bDefault);
 
@@ -337,35 +389,53 @@ QString samplv1widget_combo::valueText (void) const
 }
 
 
+float samplv1widget_combo::value (void) const
+{
+	return float(m_pComboBox->currentIndex());
+}
+
+
 // Special combo-box mode accessors.
 void samplv1widget_combo::insertItems ( int iIndex, const QStringList& items )
 {
 	m_pComboBox->insertItems(iIndex, items);
 
 	setMinimum(0.0f);
-	setMaximum(float(m_pComboBox->count() - 1));
+
+	const int iItemCount = m_pComboBox->count();
+	if (iItemCount > 0) {
+		setMaximum(float(iItemCount - 1));
+		setSingleStep(5.0f / float(iItemCount));
+	} else {
+		setMaximum(1.0f);
+		setSingleStep(1.0f);
+	}
 }
 
+
 void samplv1widget_combo::clear (void)
 {
 	m_pComboBox->clear();
 
 	setMinimum(0.0f);
 	setMaximum(1.0f);
+
+	setSingleStep(1.0f);
 }
 
 
 // Internal widget slots.
 void samplv1widget_combo::comboBoxValueChanged ( int iComboValue )
 {
-	setValue(float(iComboValue));
+	samplv1widget_knob::setValue(float(iComboValue));
 }
 
 
 // Reimplemented mouse-wheel stepping.
 void samplv1widget_combo::wheelEvent ( QWheelEvent *pWheelEvent )
 {
-	int delta = (pWheelEvent->delta() / 120);
+	const int delta
+		= (pWheelEvent->delta() / 120);
 	if (delta) {
 		float fValue = value() + float(delta);
 		if (fValue < minimum())
